@@ -4,7 +4,7 @@
 # single date for the entire project.
 # [0]: https://groups.google.com/forum/#!topic/sphinx-dev/6G8TWtIVN14
 
-import datetime
+from datetime import datetime
 import os
 import subprocess
 
@@ -19,13 +19,12 @@ def _get_last_updated(app, pagename):
     if os.path.exists(src_file):
         try:
             last_updated_t = subprocess.check_output(
-                [
-                    'git', 'log', '-n1', '--format=%ad', '--date=short',
-                    '--', src_file,
-                ]
+            [
+                'git', 'log', '-n1', '--format=%ad', '--date=unix',
+                '--', src_file,
+            ]
             ).decode('utf-8').strip()
-            last_updated = datetime.datetime.strptime(last_updated_t,
-                                                      '%Y-%m-%d')
+            last_updated = datetime.fromtimestamp(int(last_updated_t))
         except (ValueError, subprocess.CalledProcessError):
             pass
     return last_updated
@@ -37,3 +36,8 @@ def html_page_context(app, pagename, templatename, context, doctree):
 
 def setup(app):
     app.connect('html-page-context', html_page_context)
+    return {
+        'version': '0.3.0',
+        'parallel-read-safe': True,
+        'parallel-write-safe': True
+    }
